@@ -4,7 +4,7 @@ from subprocess import call
 
 seconds_listen_channel = 5*60 # seconds
 my_username = "fenton"
-debug = True
+debug = False
 monitored_channels = {} # "channel_name": time_i_last_chatted
 the_printer = None
 
